@@ -130,7 +130,7 @@ class Connection(object):
 
         if port is None:
             port = 9000
-        self._transport = TSocket.TSocket(host, port)
+        self._transport = TSocket.TSocket(host, port, socket_keepalive=True)
         self._transport = TTransport.TBufferedTransport(self._transport)
 
         protocol = TBinaryProtocol.TBinaryProtocol(self._transport)
@@ -259,8 +259,6 @@ class Cursor(common.DBAPICursor):
         """Prepare and execute a database operation (query or command).
         Return values are not defined.
         """
-        socket.setdefaulttimeout(6000)
-
         # Prepare statement
         if parameters is None:
             sql = operation
@@ -281,7 +279,6 @@ class Cursor(common.DBAPICursor):
 
     def _fetch_more(self):
         batch_size = self._arraysize
-        cursor.connection.reopen()
         self._data = list()
         for i in range(batch_size):
             row = self.fetchone()
